# sdkms/v1.AWSApi

All URIs are relative to *https://apps.smartkey.io*

Method | HTTP request | Description
------------- | ------------- | -------------
[**cancel_deletion**](AWSApi.md#cancel_deletion) | **POST** /crypto/v1/keys/{key-id}/cancel_deletion | Cancel scheduled deletion of an AWS KMS key
[**delete_key_material**](AWSApi.md#delete_key_material) | **POST** /crypto/v1/keys/{key-id}/delete_key_material | Delete the key material of an AWS KMS key
[**restore**](AWSApi.md#restore) | **POST** /crypto/v1/keys/{key-id}/restore | Restore an AWS KMS key from its source key material
[**schedule_deletion**](AWSApi.md#schedule_deletion) | **POST** /crypto/v1/keys/{key-id}/schedule_deletion | Schedule an AWS KMS key for deletion


# **cancel_deletion**
> KeyObject cancel_deletion(key_id)

Cancel scheduled deletion of an AWS KMS key

Cancel scheduled deletion of an AWS KMS key

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.AWSApi(sdkms/v1.ApiClient(configuration))
key_id = 'key_id_example' # str | kid of security object

try: 
    # Cancel scheduled deletion of an AWS KMS key
    api_response = api_instance.cancel_deletion(key_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AWSApi->cancel_deletion: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **str**| kid of security object | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_key_material**
> KeyObject delete_key_material(key_id)

Delete the key material of an AWS KMS key

Delete the key material of an AWS KMS key

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.AWSApi(sdkms/v1.ApiClient(configuration))
key_id = 'key_id_example' # str | kid of security object

try: 
    # Delete the key material of an AWS KMS key
    api_response = api_instance.delete_key_material(key_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AWSApi->delete_key_material: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **str**| kid of security object | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **restore**
> KeyObject restore(key_id)

Restore an AWS KMS key from its source key material

Restore an AWS key from its source key material

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.AWSApi(sdkms/v1.ApiClient(configuration))
key_id = 'key_id_example' # str | kid of security object

try: 
    # Restore an AWS KMS key from its source key material
    api_response = api_instance.restore(key_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AWSApi->restore: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **str**| kid of security object | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **schedule_deletion**
> KeyObject schedule_deletion(key_id, body)

Schedule an AWS KMS key for deletion

Schedule an AWS KMS key for deletion

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.AWSApi(sdkms/v1.ApiClient(configuration))
key_id = 'key_id_example' # str | kid of security object
body = sdkms/v1.ScheduleDeletionRequest() # ScheduleDeletionRequest | Request to schedule deletion for an AWS KMS key

try: 
    # Schedule an AWS KMS key for deletion
    api_response = api_instance.schedule_deletion(key_id, body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AWSApi->schedule_deletion: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **str**| kid of security object | 
 **body** | [**ScheduleDeletionRequest**](ScheduleDeletionRequest.md)| Request to schedule deletion for an AWS KMS key | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

