# sdkms/v1.DigestApi

All URIs are relative to *https://apps.smartkey.io*

Method | HTTP request | Description
------------- | ------------- | -------------
[**batch_mac**](DigestApi.md#batch_mac) | **POST** /crypto/v1/keys/batch/mac | Batch MAC with one or more keys
[**batch_mac_verify**](DigestApi.md#batch_mac_verify) | **POST** /crypto/v1/keys/batch/macverify | Batch MAC Verify with one or more keys
[**compute_digest**](DigestApi.md#compute_digest) | **POST** /crypto/v1/digest | Compute a message digest of data
[**compute_mac**](DigestApi.md#compute_mac) | **POST** /crypto/v1/keys/{key-id}/mac | Compute MAC using a key
[**compute_mac_ex**](DigestApi.md#compute_mac_ex) | **POST** /crypto/v1/mac | Compute MAC using a key
[**verify_mac**](DigestApi.md#verify_mac) | **POST** /crypto/v1/keys/{key-id}/macverify | Verify MAC using a key
[**verify_mac_ex**](DigestApi.md#verify_mac_ex) | **POST** /crypto/v1/macverify | Verify MAC using a key


# **batch_mac**
> BatchMacResponse batch_mac(body)

Batch MAC with one or more keys

Message to compute a cryptographic Message Authentication Code and the key ids to be used are provided in the request body. The MAC is returned in the response body. The ordering of the body matches the ordering of the request. An individual status code is returned for each batch item. Maximum size of the entire batch request is 512 KB. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.DigestApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.BatchMacRequest() # BatchMacRequest | Batch MAC request

try: 
    # Batch MAC with one or more keys
    api_response = api_instance.batch_mac(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DigestApi->batch_mac: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**BatchMacRequest**](BatchMacRequest.md)| Batch MAC request | 

### Return type

[**BatchMacResponse**](BatchMacResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **batch_mac_verify**
> BatchVerifyResponse batch_mac_verify(body)

Batch MAC Verify with one or more keys

The data to be MACed, the algorithm, a pre-computed MAC are provided in the request body, and the key id to be used are provided in the request body. The MAC is returned in the response body. The ordering of the body matches the ordering of the request. An individual status code is returned for each batch item. Maximum size of the entire batch request is 512 KB. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.DigestApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.BatchMacVerifyRequest() # BatchMacVerifyRequest | Batch MAC verify request

try: 
    # Batch MAC Verify with one or more keys
    api_response = api_instance.batch_mac_verify(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DigestApi->batch_mac_verify: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**BatchMacVerifyRequest**](BatchMacVerifyRequest.md)| Batch MAC verify request | 

### Return type

[**BatchVerifyResponse**](BatchVerifyResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **compute_digest**
> DigestResponse compute_digest(body)

Compute a message digest of data

This returns the digest of data provided in request body using the algorithm specified in request body. Maximum size of request body supported is 512KB. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.DigestApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.DigestRequest() # DigestRequest | Digest request

try: 
    # Compute a message digest of data
    api_response = api_instance.compute_digest(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DigestApi->compute_digest: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**DigestRequest**](DigestRequest.md)| Digest request | 

### Return type

[**DigestResponse**](DigestResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **compute_mac**
> MacGenerateResponse compute_mac(key_id, body)

Compute MAC using a key

Compute a cryptographic Message Authentication Code on a message using a symmetric key. The key must have the MACGenerate operation enabled. Asymmetric keys may not be used to generate MACs. They can be used with the sign and verify operations. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.DigestApi(sdkms/v1.ApiClient(configuration))
key_id = 'key_id_example' # str | kid of security object
body = sdkms/v1.MacGenerateRequest() # MacGenerateRequest | MAC generation request

try: 
    # Compute MAC using a key
    api_response = api_instance.compute_mac(key_id, body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DigestApi->compute_mac: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **str**| kid of security object | 
 **body** | [**MacGenerateRequest**](MacGenerateRequest.md)| MAC generation request | 

### Return type

[**MacGenerateResponse**](MacGenerateResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **compute_mac_ex**
> MacGenerateResponse compute_mac_ex(body)

Compute MAC using a key

Compute a cryptographic Message Authentication Code on a message using a symmetric key. The key must have the MACGenerate operation enabled. Asymmetric keys may not be used to generate MACs. They can be used with the sign and verify operations. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.DigestApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.MacGenerateRequestEx() # MacGenerateRequestEx | MAC generation request

try: 
    # Compute MAC using a key
    api_response = api_instance.compute_mac_ex(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DigestApi->compute_mac_ex: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**MacGenerateRequestEx**](MacGenerateRequestEx.md)| MAC generation request | 

### Return type

[**MacGenerateResponse**](MacGenerateResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **verify_mac**
> MacVerifyResponse verify_mac(key_id, body)

Verify MAC using a key

The data to be MACed, the algorithm, and a pre-computed MAC are provided in the request body, and the key id is provided in the URL. SDKMS computes the MAC of the data and compares it with the specified MAC, and returns the outcome of the MAC verification in the response body. Maximum size of request body supported is 512KB. Supported digest algorithms are - SHA1, SHA256, SHA384, and SHA512.             

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.DigestApi(sdkms/v1.ApiClient(configuration))
key_id = 'key_id_example' # str | kid of security object
body = sdkms/v1.MacVerifyRequest() # MacVerifyRequest | MAC Verify request

try: 
    # Verify MAC using a key
    api_response = api_instance.verify_mac(key_id, body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DigestApi->verify_mac: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **str**| kid of security object | 
 **body** | [**MacVerifyRequest**](MacVerifyRequest.md)| MAC Verify request | 

### Return type

[**MacVerifyResponse**](MacVerifyResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **verify_mac_ex**
> MacVerifyResponse verify_mac_ex(body)

Verify MAC using a key

The data to be MACed, the algorithm, and a pre-computed MAC are provided in the request body, and the key id is provided in the URL. SDKMS computes the MAC of the data and compares it with the specified MAC, and returns the outcome of the MAC verification in the response body. Maximum size of request body supported is 512KB. Supported digest algorithms are - SHA1, SHA256, SHA384, and SHA512. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.DigestApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.MacVerifyRequestEx() # MacVerifyRequestEx | MAC Verify request

try: 
    # Verify MAC using a key
    api_response = api_instance.verify_mac_ex(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DigestApi->verify_mac_ex: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**MacVerifyRequestEx**](MacVerifyRequestEx.md)| MAC Verify request | 

### Return type

[**MacVerifyResponse**](MacVerifyResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

