# sdkms/v1.PluginsApi

All URIs are relative to *https://apps.smartkey.io*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_plugin**](PluginsApi.md#create_plugin) | **POST** /sys/v1/plugins | Create a new plugin
[**delete_plugin**](PluginsApi.md#delete_plugin) | **DELETE** /sys/v1/plugins/{plugin-id} | Delete plugin
[**get_plugin**](PluginsApi.md#get_plugin) | **GET** /sys/v1/plugins/{plugin-id} | Get a specific plugin
[**get_plugins**](PluginsApi.md#get_plugins) | **GET** /sys/v1/plugins | Get all plugins
[**invoke_plugin**](PluginsApi.md#invoke_plugin) | **POST** /sys/v1/plugins/{plugin-id} | Invoke a plugin
[**sys_v1_plugins_invoke_plugin_id_get**](PluginsApi.md#sys_v1_plugins_invoke_plugin_id_get) | **GET** /sys/v1/plugins/invoke/{plugin-id} | Invoke a plugin using GET.
[**update_plugin**](PluginsApi.md#update_plugin) | **PATCH** /sys/v1/plugins/{plugin-id} | Update a plugin


# **create_plugin**
> Plugin create_plugin(body)

Create a new plugin

Create a new plugin with the specified properties.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.PluginsApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.PluginRequest() # PluginRequest | Properties of plugin to create

try: 
    # Create a new plugin
    api_response = api_instance.create_plugin(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling PluginsApi->create_plugin: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**PluginRequest**](PluginRequest.md)| Properties of plugin to create | 

### Return type

[**Plugin**](Plugin.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_plugin**
> delete_plugin(plugin_id)

Delete plugin

Remove a plugin from SDKMS.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.PluginsApi(sdkms/v1.ApiClient(configuration))
plugin_id = 'plugin_id_example' # str | Plugin Identifier

try: 
    # Delete plugin
    api_instance.delete_plugin(plugin_id)
except ApiException as e:
    print("Exception when calling PluginsApi->delete_plugin: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **plugin_id** | **str**| Plugin Identifier | 

### Return type

void (empty response body)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_plugin**
> Plugin get_plugin(plugin_id)

Get a specific plugin

Look up plugin by plugin ID.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.PluginsApi(sdkms/v1.ApiClient(configuration))
plugin_id = 'plugin_id_example' # str | Plugin Identifier

try: 
    # Get a specific plugin
    api_response = api_instance.get_plugin(plugin_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling PluginsApi->get_plugin: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **plugin_id** | **str**| Plugin Identifier | 

### Return type

[**Plugin**](Plugin.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_plugins**
> list[Plugin] get_plugins(group_id=group_id, sort=sort, start=start, limit=limit, offset=offset)

Get all plugins

Get details of all plugins the current user has access to.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.PluginsApi(sdkms/v1.ApiClient(configuration))
group_id = 'group_id_example' # str | Only retrieve plugins in the specified group. (optional)
sort = 'sort_example' # str | This specifies the property (`plugin_id` only, for now) and order (ascending or descending) with which to sort the apps. By default, plugins are sorted by `plugin_id` in ascending order. The syntax is \"<property>:[asc|desc]\" (e.g. \"plugin_id:desc\") or just \"<property>\" (ascending order by default).  (optional)
start = 'start_example' # str | If provided, this must be a value of the property specified in `sort`. Returned apps will begin just above or just below this value (for asc/desc order resp.).  (optional)
limit = 56 # int | Maximum number of apps to return. If not provided, the limit is 100. (optional)
offset = 56 # int | Number of apps past `start` to skip. (optional)

try: 
    # Get all plugins
    api_response = api_instance.get_plugins(group_id=group_id, sort=sort, start=start, limit=limit, offset=offset)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling PluginsApi->get_plugins: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **group_id** | **str**| Only retrieve plugins in the specified group. | [optional] 
 **sort** | **str**| This specifies the property (&#x60;plugin_id&#x60; only, for now) and order (ascending or descending) with which to sort the apps. By default, plugins are sorted by &#x60;plugin_id&#x60; in ascending order. The syntax is \&quot;&lt;property&gt;:[asc|desc]\&quot; (e.g. \&quot;plugin_id:desc\&quot;) or just \&quot;&lt;property&gt;\&quot; (ascending order by default).  | [optional] 
 **start** | **str**| If provided, this must be a value of the property specified in &#x60;sort&#x60;. Returned apps will begin just above or just below this value (for asc/desc order resp.).  | [optional] 
 **limit** | **int**| Maximum number of apps to return. If not provided, the limit is 100. | [optional] 
 **offset** | **int**| Number of apps past &#x60;start&#x60; to skip. | [optional] 

### Return type

[**list[Plugin]**](Plugin.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **invoke_plugin**
> PluginInvokeResponse invoke_plugin(plugin_id, body)

Invoke a plugin

Invokes a plugin execution with the provided request body as input to the plugin.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.PluginsApi(sdkms/v1.ApiClient(configuration))
plugin_id = 'plugin_id_example' # str | Plugin Identifier
body = sdkms/v1.PluginInvokeRequest() # PluginInvokeRequest | Object to be passed to plugin as input

try: 
    # Invoke a plugin
    api_response = api_instance.invoke_plugin(plugin_id, body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling PluginsApi->invoke_plugin: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **plugin_id** | **str**| Plugin Identifier | 
 **body** | [**PluginInvokeRequest**](PluginInvokeRequest.md)| Object to be passed to plugin as input | 

### Return type

[**PluginInvokeResponse**](PluginInvokeResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **sys_v1_plugins_invoke_plugin_id_get**
> PluginInvokeResponse sys_v1_plugins_invoke_plugin_id_get(plugin_id)

Invoke a plugin using GET.

Invokes a plugin with empty input.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.PluginsApi(sdkms/v1.ApiClient(configuration))
plugin_id = 'plugin_id_example' # str | Plugin Identifier

try: 
    # Invoke a plugin using GET.
    api_response = api_instance.sys_v1_plugins_invoke_plugin_id_get(plugin_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling PluginsApi->sys_v1_plugins_invoke_plugin_id_get: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **plugin_id** | **str**| Plugin Identifier | 

### Return type

[**PluginInvokeResponse**](PluginInvokeResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update_plugin**
> App update_plugin(plugin_id, body)

Update a plugin

Change a plugin's properties, such as name, description, code, or group membership.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.PluginsApi(sdkms/v1.ApiClient(configuration))
plugin_id = 'plugin_id_example' # str | Plugin Identifier
body = sdkms/v1.PluginRequest() # PluginRequest | Properties of plugin to create

try: 
    # Update a plugin
    api_response = api_instance.update_plugin(plugin_id, body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling PluginsApi->update_plugin: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **plugin_id** | **str**| Plugin Identifier | 
 **body** | [**PluginRequest**](PluginRequest.md)| Properties of plugin to create | 

### Return type

[**App**](App.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

