# sdkms/v1.StatsApi

All URIs are relative to *https://apps.smartkey.io*

Method | HTTP request | Description
------------- | ------------- | -------------
[**get_app_stats**](StatsApi.md#get_app_stats) | **GET** /sys/v1/stats/{app-id}/app | Get transaction statistics for a specific application
[**get_apps_stats**](StatsApi.md#get_apps_stats) | **GET** /sys/v1/stats/apps | Get app aggregate transaction statistics
[**get_group_stats**](StatsApi.md#get_group_stats) | **GET** /sys/v1/stats/{group-id}/group | Get transaction statistics for a specific group
[**get_groups_stats**](StatsApi.md#get_groups_stats) | **GET** /sys/v1/stats/groups | Get group aggregate transaction statistics
[**get_security_object_stats**](StatsApi.md#get_security_object_stats) | **GET** /sys/v1/stats/{key-id}/key | Get transaction statistics for a specific security object


# **get_app_stats**
> StatsResponse get_app_stats(app_id, range_from=range_from, range_to=range_to, num_points=num_points)

Get transaction statistics for a specific application

This API is for obtaining transaction statistics for a specific application. API supports query parameters for fetchings stats for specific time period and with number of data points desired.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.StatsApi(sdkms/v1.ApiClient(configuration))
app_id = 'app_id_example' # str | Application Identifier
range_from = 56 # int | Starting time for search , this is EPOCH value (optional)
range_to = 56 # int | Ending time for search , this is EPOCH value (optional)
num_points = 56 # int | Number of data points desired (optional)

try: 
    # Get transaction statistics for a specific application
    api_response = api_instance.get_app_stats(app_id, range_from=range_from, range_to=range_to, num_points=num_points)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling StatsApi->get_app_stats: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **app_id** | **str**| Application Identifier | 
 **range_from** | **int**| Starting time for search , this is EPOCH value | [optional] 
 **range_to** | **int**| Ending time for search , this is EPOCH value | [optional] 
 **num_points** | **int**| Number of data points desired | [optional] 

### Return type

[**StatsResponse**](StatsResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_apps_stats**
> StatsResponse get_apps_stats(range_from=range_from, range_to=range_to, top_count=top_count, num_points=num_points)

Get app aggregate transaction statistics

This is for obtaining app level aggregate transaction statistics to find top apps by transaction. API supports query parameters for fetchings stats for specific time period, for maximum top count and with number of data points desired.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.StatsApi(sdkms/v1.ApiClient(configuration))
range_from = 56 # int | Starting time for search , this is EPOCH value (optional)
range_to = 56 # int | Ending time for search , this is EPOCH value (optional)
top_count = 56 # int | Maximum top count for statistics query (optional)
num_points = 56 # int | Number of data points desired (optional)

try: 
    # Get app aggregate transaction statistics
    api_response = api_instance.get_apps_stats(range_from=range_from, range_to=range_to, top_count=top_count, num_points=num_points)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling StatsApi->get_apps_stats: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **range_from** | **int**| Starting time for search , this is EPOCH value | [optional] 
 **range_to** | **int**| Ending time for search , this is EPOCH value | [optional] 
 **top_count** | **int**| Maximum top count for statistics query | [optional] 
 **num_points** | **int**| Number of data points desired | [optional] 

### Return type

[**StatsResponse**](StatsResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_group_stats**
> StatsResponse get_group_stats(group_id, range_from=range_from, range_to=range_to, num_points=num_points)

Get transaction statistics for a specific group

This API is for obtaining transaction statistics for a specific group. API supports query parameters for fetchings stats for specific time period and with number of data points desired.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.StatsApi(sdkms/v1.ApiClient(configuration))
group_id = 'group_id_example' # str | Group Identifier
range_from = 56 # int | Starting time for search , this is EPOCH value (optional)
range_to = 56 # int | Ending time for search , this is EPOCH value (optional)
num_points = 56 # int | Number of data points desired (optional)

try: 
    # Get transaction statistics for a specific group
    api_response = api_instance.get_group_stats(group_id, range_from=range_from, range_to=range_to, num_points=num_points)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling StatsApi->get_group_stats: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **group_id** | **str**| Group Identifier | 
 **range_from** | **int**| Starting time for search , this is EPOCH value | [optional] 
 **range_to** | **int**| Ending time for search , this is EPOCH value | [optional] 
 **num_points** | **int**| Number of data points desired | [optional] 

### Return type

[**StatsResponse**](StatsResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_groups_stats**
> StatsResponse get_groups_stats(range_from=range_from, range_to=range_to, top_count=top_count, num_points=num_points)

Get group aggregate transaction statistics

This is for obtaining group level aggregate transaction statistics to find top groups by transaction. API supports query parameters for fetchings stats for specific time period, for maximum top count and with number of data points desired.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.StatsApi(sdkms/v1.ApiClient(configuration))
range_from = 56 # int | Starting time for search , this is EPOCH value (optional)
range_to = 56 # int | Ending time for search , this is EPOCH value (optional)
top_count = 56 # int | Maximum top count for statistics query (optional)
num_points = 56 # int | Number of data points desired (optional)

try: 
    # Get group aggregate transaction statistics
    api_response = api_instance.get_groups_stats(range_from=range_from, range_to=range_to, top_count=top_count, num_points=num_points)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling StatsApi->get_groups_stats: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **range_from** | **int**| Starting time for search , this is EPOCH value | [optional] 
 **range_to** | **int**| Ending time for search , this is EPOCH value | [optional] 
 **top_count** | **int**| Maximum top count for statistics query | [optional] 
 **num_points** | **int**| Number of data points desired | [optional] 

### Return type

[**StatsResponse**](StatsResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_security_object_stats**
> StatsResponse get_security_object_stats(key_id, range_from=range_from, range_to=range_to, num_points=num_points)

Get transaction statistics for a specific security object

This API is for obtaining transaction statistics for a specific security object. API supports query parameters for fetchings stats for specific time period and with number of data points desired.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.StatsApi(sdkms/v1.ApiClient(configuration))
key_id = 'key_id_example' # str | kid of security object
range_from = 56 # int | Starting time for search , this is EPOCH value (optional)
range_to = 56 # int | Ending time for search , this is EPOCH value (optional)
num_points = 56 # int | Number of data points desired (optional)

try: 
    # Get transaction statistics for a specific security object
    api_response = api_instance.get_security_object_stats(key_id, range_from=range_from, range_to=range_to, num_points=num_points)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling StatsApi->get_security_object_stats: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **str**| kid of security object | 
 **range_from** | **int**| Starting time for search , this is EPOCH value | [optional] 
 **range_to** | **int**| Ending time for search , this is EPOCH value | [optional] 
 **num_points** | **int**| Number of data points desired | [optional] 

### Return type

[**StatsResponse**](StatsResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

